;; skip.el
;;
;; System of Kanji Indexing by Patterns
;;
;; compiled by Werner Lemberg <wl@gnu.org>
;;
;; Version 1.1 20-Aug-1998
;;
;;
;; SKIP (System of Kanji Indexing by Patterns) numbers are derived from the
;; New Japanese-English Character Dictionary (Kenkyusha 1990, NTC 1993) and
;; The Kodansha Kanji Learner's Dictionary (Kodansha International, 1998). 
;; SKIP is protected by copyright, copyleft and patent laws.  The commercial
;; or non-commercial utilization of SKIP in any form is strictly forbidden
;; without the written permission of Jack Halpern, the copyright holder. 
;; Such permission is normally granted.  Please contact jhalpern@kanji.org
;; and/or http://kanji.org (or www.win.or.jp/~jhalpern if not accessible).
;;
;;
;; The SKIP data has been mechanically extracted from the kanjidic
;; database.

(require 'quail)

(quail-define-package "japanese-skip" "Japanese" "SKIP"
 t
 "SKIP input method developed by Jack Halpern.

    SKIP input code xyy[zz]:

        values for x:

            1    character can be split vertically.
                 yy and zz are the number of strokes on the left and
                 right side respectively.

                 Example: 10307: $B0"(B

            2    character can be split horizontally.
                 yy and zz are the number of strokes on the top and
                 bottom side respectively.

                 Example: 20603: $B4,(B

            3    character has `enclosure', i.e., a logical group of
                 strokes which encloses the character at least on two
                 sides.
                 yy and zz are the number of the enclosing and
                 enclosed strokes respectively.

                 Examples: 30313: $BT((B
                           30607: $B:\(B

            4    characters which do not fit in one of the above
                 categories.
                 yy is the number of total strokes.

                 Examples: 406: $B<+(B
                           412: $B4v(B

The breakline between xx and yy is the FIRST LOGICAL break possibility.
E.g. $B0U(B has the input code 20211 (and not 20508) because $BP5(B is the
first logical unit. This logical unit must have at least two strokes.

A more thorough introduction can be found in the documentation of the
kanjidic database at

  ftp://ftp.cc.monash.edu.au/pub/nihongo/kanjidic.doc.Z
"
 '(
    ("\C-?" . quail-delete-last-char)
    (">" . quail-next-translation)
    ("." . quail-next-translation)
    ("<" . quail-prev-translation)
    ("," . quail-prev-translation)
  )
 nil nil nil nil)


(quail-define-rules
("10101"	"$BH,Q9(B")
("10102"	"$B>.@nV_(B")
("10103"	"$B?4?e(B")
("10104"	"$B5lI,(B")
("10107"	"$B>5(B")
("10108"	"$B0}(B")
("10111"	"$B=g(B")
("10202"	"$B2=4"5X=:?N@ZAPHfJ)P:P;P=P>(B")
("10203"	"$B0J2C;E;F@gB>BeI9IUP%P?P@PAPBb"(B")
("10204"	"$B0K2>4l5Y6D7o8`<!=#CgEAG$H2IzPCPDPgQSQTQUQVZ?Z@(B")
("10205"	"$B0L2?2@:4:c:n;G;w=;?-BNC"DQDcGlH<LjM$NbNdPEPFPGPHPIPJQWU$ZA(B")
("10206"	"$B0M2A2B4&6!6"6(8s;H;xInJ;KyNcPKPLPMPNPOPPPQPRPSQXU%(B")
("10207"	"$B2d788t=S?.?/B%B/JXJ]KsN7PWPXPZP[P\P]P^P_P`(B")
("10208"	"$B265"6f7p7q8D8u8v<Z=$=Z@(CMC|E]E`GPG\I6JoJpN?NQOAPaPbPcPdPePfPhPiPjPkPlPmPnPoQYQZ(B")
("10209"	"$B566v7r:"<EB&D:DdDeJPPpPqPsPtPuPvPwPxPy[j`Gf{(B")
("10210"	"$B0NGnHwK5PzP{P|qH(B")
("10211"	"$B6O797f:D:E=}ANF/H7MCP}P~Q"Q#Q$e6rl(B")
("10212"	"$B6#A|KMN=Q%Q&Q'Q(Q)Q*(B")
("10213"	"$B2/57JHQ+Q,Q-Q.Q/Q[t%(B")
("10214"	"$B6E<tPVQ0Q1Q2Q3(B")
("10215"	"$B=~M%Q4(B")
("10216"	"$BLY(B")
("10219"	"$BQ5Q6(B")
("10220"	"$BQ7Q8(B")
("10301"	"$B0z889&V&Y)(B")
("10302"	"$B1,303p4)8y9*90<8<}=ABGC!DuE[HEHHJ'KLMDQdRIRZR[R\R]T)(B")
("10303"	"$B071%1)1x4@5I5[6+9%9>9T<.ATBqCOCPCSC]C{EGFrG!HAHFH^K;R^T*T+U!U"V(VtWVY*Y+Y,Y-Y.]h]i`<ggot(B")
("10304"	"$B2-2w2~4t5%585;5b686Q6c7h9#9396:;:d:e;Z>6>u?a@^A$BABrBtD@EjFYG%GDH4HcI^J-J1K7K8KIKJKWL/LrMEM^M`R_R`RaRbRcRdReRfRhT,T-T.T/U&U+WGWWWXWYWZX-Y/Y0Y1Y2Y3Y4Y5Y7Y8]j]k]l]m]n]o]p]q]r]s]t^"`;`=`>`?ouovow(B")
("10305"	"$B0$091K1h1}2!2O2x2}3H5c5q5r61676i7B898F8H8Q949}:%:p;O;P<#<v>7>B@+@,@-@[A;A@AKBKBsC3C4CjCmD!DZDqE%EJGHGRGoGqH`HdHgI]ImJ(JzK!K"KeKuKwL#L(LoL}NgRiRjRlRmRnRqRrRsRtRuRvT0T3T4T5U'U(V-V.V/V0V1V2V3VeWHWIWJW^W`WaWbWeWfWgWhWiWjY6Y9Y:Y;Y>Y@YBYCYDYEYFYGZ-]b]u]v]w]x]y]z]{]|]}]~^!^#^$^%`@`Aox(B")
("10306"	"$B0#0(0D0v0y181L2y2z3$313@3f3g3h4/6.64698B8I8L8e9$919?9i:(:i;";X;}<m=&='>k>t?!@u@vBTD)DEF6F=FHGILEMNMlN'RwRzR{R|R}S"S#S$S&S>T6T7T8T9T:T;U)U,U-UXV5W9WKWLWNW_WmWoWpWqWrWtWuWvWwWxYHYIYJYKYLYNYO^&^'^(^)^*^+^,^-^.^/^0`B`C`Doyozo{(B")
("10307"	"$B0"0'1!141:1Y2e3=4Y8d8g9@9_:6;+<r=>=T=y=|>%>->C?1?6?;?XA\A^B*B9BoC,D=DpDrELEsFBG:GbHTI1IMIbJEJaJvKdKiL<M0MaN.N^O2O5S(S)S*S+S,S.S/T<T=T>T?T@TBU.U/U1U2U3V7V8V9V;WMWzW{W}W~X!X"X#X$X%X&X'YMYPYQYRYT^1^2^3^4^5^6^7^8^:`E`Fo~(B")
("10308"	"$B0T0h0|1"1U1f363]3e3i5E6/6?7!7G7L7~81959{:':.:C:N:Q:j:k;4<N<x=B=J=Q=_=m>'>+>9>D>p>}?<?d?x@6@K@\A<A]A_BCBOC5C8CvD"D%DDE:EiEqF+F@FWFhG-G1GSG]GfIAIVIXJZJ{KYLTM#MdN&N+N4NCNDNMNTS0S1S2S3S5S6S7S8S9S:S;TCTDU4U5U6U7U9V=VAVDVEVGViW:WOWPWQWRW|X)X+X,X.X/X0X1YUYVYWYXYYY[Y\Y]Y^Y_Y`^;^<^=^>^?^@^A^B^C^D^E^F^G^H^I^J^K^L^M^N`H`I`J`K`LjJo|o}p!p"p#(B")
("10309"	"$B0.0/121a1g293,394!4-4.494x5J6*6t6y7(7v8:8P8f9"929A9`:f<"<>=[>E>l?\?oB,B7BFBbC9CFC}DMDiDsEHEOEcEkErG^I+I2I|I}J%J=K9K~L+L;L{M,M/M1MHMIM[OQS<S=S?S@SBSCSDSFSGSHSISJTETFTNTfU;VJVKVjVkVlWSX3X5X7X8X9X:X;X<X=X?YaYbYcYdYeYfYgYhYi^O^P^Q^R^S^T^U^V^W^X^Y^Z^[^\^]^^^_^a^b^c`M`N`O`Pp$p%(B")
("10310"	"$B0n1n1v2G2^2t343V3j4A7H7d7y8;9B:7:q;b<;?5@]B;BZBlC2E.E6EdGyH9HBHyKZLGMON/NzSKSLSMSNSOSPSQTITMU<U=U>U?U@ULVNVmW;WTX2XAXCXDXFXHXIXKYSYjYlYmYnYoYqYrYs^d^e^f^g^h^i^j^k^l^m^o^p^q^r`Qg!jKp&(B")
("10311"	"$B1#1i474C5y6-9v9w:]<?>c@"A2A9AfA}A~CdD'DODRE&E)EhFAI:K}L!LDLNO3SRSSSTSUSVSWSXTGUAUBUCUDUEVOVQVnVoXLXMXNXPXRXSXTXUXVXXXYYtYvYw^`^t^v^w^x^z^{^|^}^~_!_"_#`Snrp'p(p)(B")
("10312"	"$B131=3I3c3z4B4r7i;#;5=a>W>|@!@q@xD,DYE0E1F4F5G2GEH(H.IoJ.J/J0KPSYS\S]S^S_TQTRTSTWUFUGUHUIVRVSVpVqW<X]X^X_XbXcYyYzY{Y|Y}_$_%_&_'_(_)_*_,_-_._/_0_1_3_L`UsU(B")
("10313"	"$B1R212u2{3M48607c9U>m>nA`ByCEECFUG;H8MJNYNyS`SaSbScSdTTVTVUWUXdXeXhXjXkXnY?Y~Z!Z"Z#Z$Z%Z'_2_4_5_6_7_8_9_:`V`WjLn.p*(B")
("10314"	"$B3E5+5<9c9h9j;$BuD\E'G(SeSfSgSiSjTVT\UMUNU^VYW=XoZ(Z+Z,Z.Z/^9_;_<_=_>_?_@_A_B`Xoip+p,r}(B")
("10315"	"$B>qCuMtShT]XsZ1Z2Z3Z4Z6Z9_C_D_E_F_G_H_I`Zp-p.(B")
("10316"	"$B@%BmFTINSkTUT`UOXgXq_+_J_K_M_N`\(B")
("10317"	"$BSmT_TaUPUQURVZXrZ7_O_P_Q_Rp/(B")
("10318"	"$BSpSqSrSsXuXvXwYpZ8^u(B")
("10319"	"$BFgStSuZ:_S(B")
("10320"	"$BYxZ<s`(B")
("10321"	"$BSvSwZ0jM(B")
("10322"	"$B_T(B")
("10401"	"$B;%Ni(B")
("10402"	"$B0u4y5`7::!EtH)KQLFNsO>QeQf[5[6[7(B")
("10403"	"$B244N6j777A:`<R<]<^>s?yB<BPENFaI*K.MqTcU#[8[9[:[;[<[=fjfln7(B")
("10404"	"$B1w2"2$2%4a5'5@5O6U8T9:9O;^;c;h=j>>?f?u@OGGGUHDHGHnHsHzI~J*J|J~KCKRKgKmL@LgNSO'OHOP[>[A[B[C[D[E[F[G]G]H_V`.fmfo(B")
("10405"	"$B1G2Q3A4;8O8U:r:t;9;\=K><?@@7ADAjBHB[C@ClDADNDSFJG*GYGpH*I"JAK&KXKfKoLxM.M4NhPYYAZc[&[,[H[I[J[L[M[N[O[P[Q[R[S[T[U[V[W]I]J_W_Y_Z_[_\`,`2`]`^`_```ac1fpfrfsfufvfw(B")
("10406"	"$B3"3J3K3t3|4<5K6;6M7>7K7e9;:,:y;/;7;D;i;~<l<n=^>M@4@H@r@sD?EmF9FCG_HII0KqL.N9OFZSZTZVZh[Z[[[][^[_[a[b[c_]_``b`c`d`~fxfyg&(B")
("10407"	"$B041k233#3a3q5,5S5e8=8h9<:-;k>?@{B2BvC&DtEnFZG>HuIKM}N0UrZWZkZmZn[-[`[d[e[g[h[i[k[l[n[o[q[t[u]K_X_b`3`f`ifzf}(B")
("10408"	"$B0X1M4=4}6G8!9P>!>F?"?#?z@2@3C*D1DGEoExGWHCHUILK@L:LIM:NVO=OSZr[s[v[x[z[{[|[}[~\!\"\#\%\&\(\)\*\,\-\.\/\0\1\2]L]M_c_d`0`h`j`kf~g"g#g$g%(B")
("10409"	"$B0E1l2K2R4h6K8j9x:g<p=]?pA#A5BJB\CHD-D2DHDXDwFNF\FjFoG`GaHQHRIvJ!J"MBMLN{O0O1ZXZuZvZwZx\$\3\4\5\6\7\8\9\:\;\<\=\>\?\@\A\B\C\D_e_j_k_l`l`m`o`p`q`vg'g(g)g*g+g5prps(B")
("10410"	"$B1]353r4z9=:2:<;s?:@zAdKjKlLOMMMPM~N\U[Zy\E\G\H\I\J\K\L\N\O\P\R\S\T\U\V\W\X\Y\c]N_o_p`7`g`s`t`ug,g-g.g/t"t$(B")
("10411"	"$B2#2*3_8">@AeCtDPF>I(I8\Z\\\]\_\`\b\d\e\f\g\i\k\l\n\s\x]O^n`w`xg1g2g3g4g6rmrq(B")
("10412"	"$B5!5L66<y>AA7C.EuFKG3KDP.ZZZ|Z}[!["\m\o\p\q\r\t\u\v\w]P]Q_s_u_v_w_x_y`e`yeXg7g8g9(B")
("10413"	"$B223`4D5>8i;8?$AgCIF%G?NU[#[X\y\z\|\}\~],_z_{_|_}`/g:g;g<g@gE(B")
("10414"	"$B6{=lG)MKZY[$[/[m\j]#]$]%]&]'](]R_n_~`"gAgB(B")
("10415"	"$BB!GxGzK2O&[%])]*]+]-]T`#`1`9`{gD(B")
("10416"	"$BF-H'Ms['[0].`$`:`|gCgF(B")
("10417"	"$B]/]0]2]S`%`}(B")
("10418"	"$B\^(B")
("10419"	"$BgG(B")
("10421"	"$B]4(B")
("10425"	"$B]6(B")
("10502"	"$B5Q9e;d=i=uB(D.H=JLMxNeQgQhR"R#cg(B")
("10503"	"$B<YCNE!E*OBbec+chjNn8n9n:(B")
("10504"	"$B2J6^8&8N:=:U=)@/CJGjH@ICZBZQa8a9a:b'b=b>b?b@bbbfbgc>cicjjRjSjUjV(B")
("10505"	"$B4{5N6k9\<e>NAEB5CaEVEWGKGiHJHkHoK$L2a;b.bAbBbFbic,c-c/c0c?c@cAcBckclcmjWjXjYjZj[j\r((B")
("10506"	"$B0A0\4c7M8SD/L3N,a>a?b)bEbHbkcnfDjTj_j`jajb(B")
("10507"	"$B1y5)8'9E=W>K@GAAABC;DxGAH#JdM5N#N2aBaGb*b+bIbmcCcDcocpjek-(B")
("10508"	"$B102m373l:l?g?~CUDvFmI#KSL-LwMgNGORaCbJbKbLbMbNbdblbobpbqc2c3cEcFcGiKjhjijkjljmp3p5(B")
("10509"	"$B0p7[<'<o?|@YC<D*HjJ#NNb1bQbrbsbtbuc4cJcqcrjnjojpj|q%(B")
("10510"	"$B2T3N9FJfb-bRbSbTbvbwbxbzb{b|c5cKcMcNjrjsjtjur0(B")
("10511"	"$B0,2:3{7N<2@QbUbVbyc!c"jvjyjzrrrurvry(B")
("10512"	"$B0k6:>LF7KTNFbWbXbYc#c$c6c8cOcPj{p7(B")
("10513"	"$B2(3O6_=V>wACb[b]c%c&c'c9cQcRj}(B")
("10514"	"$BaFb^c(cSk!(B")
("10515"	"$Bbhbjc*k"k#k$(B")
("10516"	"$BcTk%(B")
("10517"	"$Bc:cUk&k'(B")
("10521"	"$Bba(B")
("10601"	"$BMpd}(B")
("10602"	"$B3/758z9o:~;I<h=G@)E~QiQjQkR$db(B")
("10603"	"$B0:0j5*5i5j6N9H9Y?cBQFzIuLbLmLsO:Qld~e!e}jI(B")
("10604"	"$B2c9I9L9R:s;&;U;f<S=c?hC?CQCWG<G=HLI3IRJ4J6KBL0LWLfNAO/ZC]Vdcdde"e#e~fQfRfVfWgSgUgVgdiNiOiQiRiSjH(B")
("10605"	"$B3B7P8>8?:0:Y<X=*>R?BA%AFAHBID]E<G4GtGuISN3R7a!e%e&e(e)e*e+f8f9fSfXfYgWgXiTiUiViWiXiYi[(B")
("10606"	"$B0<3(3?5k7k9J>Q@dE}H:IHMmW6[.[ydfdhdidje,e-e.e/e0e2e3fFfZi\i]i`iaib(B")
("10607"	"$B2k7Q8(<-B3DzK*dkdne4e5e7e8e9fTf[gYicidieihijikilimmd(B")
("10608"	"$B0=0]9K;(<z=o@:AmAnAoC>CXDVHlLJLVNPN}O9dodpdqe:e<e=e>e?e@eBeCeEeFeGenf^inioipiqiris(B")
("10609"	"$B1o2\4K518R@f@~A8D3DyFlGhJTKKLK^sdrdseHeIeJeKeLeMeNeOf;f_iuiviwixiyizi{i}i~j!j"j#pupv(B")
("10610"	"$B0^<J=DB}E|G{K%MfdtduePeReSeUeVeWfUgKgZg[j&j'(B")
("10611"	"$B9G=+=L@SA!AlD0N~dweAeTeYeZe\e]e^e_e`eaf!fbg\g]j)j+j,j0j2j3rwrzr{r|r~(B")
("10612"	"$B?%?&A6NHebecedeeefegg^j4j6j=(B")
("10613"	"$B5B7+aEeheiejf?g_g`j$j7j8j9j:j;j<(B")
("10614"	"$BMTdyekelemeoeqfdgaj>j?j@(B")
("10615"	"$B4OE;dzeresetevezgbiZ(B")
("10616"	"$Beue|f$gc(B")
("10617"	"$Bewey(B")
("10618"	"$Bexf%(B")
("10701"	"$BF}mB(B")
("10702"	"$B272i507W:o=vB'D<DfD{KVQmQoR&RJa<k>nD(B")
("10703"	"$B5-71748.:b<M<`?V@&BwCqF$G[I?k?k@kAl9m;n;n<n>qu(B")
("10704"	"$B3L5_5v656m7m;B<O<P<a>Y?l@_CGE>FpGTHNK,LnLuM_ZDZEZFZGZO]7]8kBkCkDl.lAlClJlelflgmCnEnFsQ(B")
("10705"	"$B1S5w7Z:>;l<4>Z>[?G?]AJBBCpCyE=I>b/k8k:kEkFkGkHkIl:lFl_lhliljlklllmm<mEmFmGnGnHnX(B")
("10706"	"$B2r3:3S5M727X8X8Y;m;n=7>\?(@?@WA'A(A)B1D7MoO(O)OCOEOMfgfhk;kKkLkMkNkOkPkQl;l<l=l\lnlplqm>mHmImJmRnI(B")
("10707"	"$B3R5?8l8m9Z9s;@;o@bFIFxG'JeKFM6MYQ>]Zk.kRkSkTkUkVkWkXl>lrlsltlumKmLmNmenJnK(B")
("10708"	"$B1Z2]5C;r=f=t?[@ABzC/CBCLD4F'GeHpIjNJNXO@kYkZk[k\k]l2l?lMlvlwlxlym)mMmOmPmQnLnMnN(B")
("10709"	"$B0b1O1P3\4R8A8o;p=4@CBiD5D|D}ERF,FfKEM!M"MXMjQ~R!k^k_k`kakbkckdkekfkgkkl7l`lzl{l|l}m?mTmUmVptpwpx(B")
("10710"	"$B3m6`8,9V9X<U=9UKkhkjklkmknkol@lQlRl~m"m#m$m%mWmYnO(B")
("10711"	"$B1-9t@XB#I5NWk<kpksktkulBm'm(m*m+mZm[m\nQnRs!s#s$s%s&(B")
("10712"	"$B<1=3E2H0Iha"kvkwkxkykzk{k|k}m,m-m.m@m](B")
("10713"	"$B5D8n>y>zepk=k~l!l#lXm/m0m1m=m^nSnTnY(B")
("10714"	"$BLvl$lYm3m4m_mgnU(B")
("10715"	"$B;>l&l[l^m5m6m7m`(B")
("10716"	"$Bl'm8mamb(B")
("10717"	"$Bl)l*l+mAnV(B")
("10718"	"$Bl,m:(B")
("10719"	"$Bl-(B")
("10720"	"$Bm9(B")
("10802"	"$B527u9d:^?KE#GmK6QpQqR'n[n\n^(B")
("10803"	"$B0S3T4%6|:L<9D&D`ETItKUM9Q{UYn_n`na(B")
("10804"	"$B0{3C4:4>4|5=6V7I7a;6;[="D+FXF_HSJsP0ZHZI]:]WnbncndnenfngoO(B")
("10805"	"$B0;1t448Z9[;L;t>`>~E4H-K0Nknhninjnknlnmnonpnqnv(B")
("10806"	"$B061B6d=F={?*@EA,A-D8F<KHLCL_Tnnnnsntnu(B")
("10807"	"$B1T2nCrIFJ^J_K/eDgTnwnxnynz(B")
("10808"	"$B4M4[4\5x6S9]:x;,<b>{?m?nIENlO#O?n{n|n}n~o!o"o#o$o%o&o'p:pP(B")
("10809"	"$B4Z7-80>aCCDJDWEUFiIQo(o)o*o+o,py(B")
("10810"	"$B3;3y:?AyDCo-o.o/o0o1r2(B")
("10811"	"$B6@7\E-L9o3o5o6o7o8o9o:o;s's(s)s+s,(B")
("10812"	"$B>bF*o<o=o>o?o@oAoE(B")
("10813"	"$BBxLzoBoCoDoF(B")
("10814"	"$Bd{oGoI(B")
("10815"	"$B4Ul(oJoKoLoMoT(B")
("10816"	"$BoN(B")
("10817"	"$BoP(B")
("10818"	"$BoQoR(B")
("10819"	"$BoSoU(B")
("10820"	"$BoW(B")
("10902"	"$B4*>jF0I{pU(B")
("10903"	"$B?YWEn?pVpW(B")
("10904"	"$B7$8%8]?7?t@oEBM2R,TLUvY"ZP];]<]=pXpqq+q,(B")
("10905"	"$B3sa+a,b0pRpYpZp[p\p]ppsi(B")
("10906"	"$B0HfIp^p`q-q.(B")
("10907"	"$B>d?FN6eQk/k0pSq/q0q1(B")
("10908"	"$B5Gj-p1paq2q3q4q5q6qE(B")
("10909"	"$B3[4i82J\N`kqpbpcpdpzp{q7qF(B")
("10910"	"$B1$pepfpkq9q:q;(B")
("10911"	"$Bq<q=s*s-s.(B")
("10912"	"$Bq>q?q@qAqB(B")
("10913"	"$Bpg(B")
("10915"	"$Bphpi(B")
("11002"	"$B3.3d6PAOQsQtQuqG(B")
("11003"	"$BCZFkn@ql(B")
("11004"	"$B1X2N6n9rBLG}]>qIqm(B")
("11005"	"$B6o6pCsb2qJqKqLqM(B")
("11006"	"$B3<M;qOqPqQqRqXqn(B")
("11007"	"$B=Yk1k2l/l0qSqTqU(B")
("11008"	"$B5383?wA{FqN%]Ep8qVqWqo(B")
("11009"	"$B4j?qBME?qY(B")
("11010"	"$B6%q[(B")
("11011"	"$BDaq\q]q_q`qps0s1s2s3s4s5s6s7s8(B")
("11012"	"$Bfeqaqb(B")
("11013"	"$Bqcqdqqqrqsqt(B")
("11014"	"$Bqe(B")
("11016"	"$Bqf(B")
("11017"	"$Bqgqh(B")
("11018"	"$Bqi(B")
("11019"	"$Bqk(B")
("11102"	"$B4+QvQwR*R+R-(B")
("11103"	"$B>4UtnA(B")
("11104"	"$B4?4e5#5:C7E(I_Y$ZK]?]Xr7rp(B")
("11105"	"$B0>9yI;J+a.a/r8r9r:r;r<rx(B")
("11106"	"$B:z;-A/Knger=r>r?r@(B")
("11107"	"$B4Q8qk3rArCrDrErFrG(B")
("11108"	"$B037_84;*BdrHrIrJrKrLrNrOrPsJ(B")
("11109"	"$B3bOLq(rQrRrSrTrUrVrWrXrYrZr\sD(B")
("11110"	"$B0sIIr[r]r^r_r`(B")
("11111"	"$B17C-Q?rMrarcrds:(B")
("11112"	"$B3oKpre(B")
("11113"	"$BNZrfrg(B")
("11114"	"$Bd|(B")
("11115"	"$Brh(B")
("11116"	"$Bri(B")
("11201"	"$BP,(B")
("11202"	"$B3D(B")
("11203"	"$B1FE"nB(B")
("11204"	"$B=CY%]@]A`TsX(B")
("11205"	"$BNpsVsYsZs[sd(B")
("11206"	"$BK]s\(B")
("11207"	"$Bmfse(B")
("11208"	"$Bs](B")
("11209"	"$B8\fLq*s_(B")
("11210"	"$BXt(B")
("11211"	"$Bs;s<s=s>sW(B")
("11212"	"$BpL(B")
("11215"	"$Bsb(B")
("11302"	"$B7`N-Qx(B")
("11303"	"$BQyQznC(B")
("11304"	"$BY&ZL]B]amX(B")
("11306"	"$B1p(B")
("11309"	"$Bp|(B")
("11402"	"$B1CQ}R.(B")
("11403"	"$BiLsm(B")
("11404"	"$BY'ZR]C(B")
("11409"	"$Bp}(B")
("11502"	"$BR/sp(B")
("11504"	"$B`Y(B")
("11505"	"$Bsqsrssst(B")
("11506"	"$Bsu(B")
("11507"	"$Bk6swsx(B")
("11509"	"$Bsyszs{(B")
("11604"	"$B`[(B")
("11609"	"$Bq!(B")
("11711"	"$Bs@(B")
("11802"	"$BR0(B")
("11804"	"$B]D(B")
("11806"	"$Bgf(B")
("11807"	"$Bk7(B")
("11809"	"$Bq"q#(B")
("11811"	"$BsA(B")
("20101"	"$BFsQR(B")
("20102"	"$B;0WDWF(B")
("20103"	"$B1>858MK3(B")
("20104"	"$B1J<(<g(B")
("20105"	"$BOK(B")
("20106"	"$B7O8@F&La(B")
("20107"	"$B8*K<(B")
("20109"	"$B@pZir/(B")
("20110"	"$Bn=(B")
("20111"	"$B8[Hb(B")
("20201"	"$B8pP$(B")
("20202"	"$B0t2p7g8a8x:#;Y>iIcJ,J8J}M=O;P6QBR@RFZ=Z>]U]c`+(B")
("20203"	"$B8<8E;T<L>$@jBfJ[L7LpN)NaRCUTUu(B")
("20204"	"$B0a0g2q4L4k8r9g;]<)=<?'A4AhG/I4KhKrL6LQ[4(B")
("20205"	"$B3Q4^4u5|9n?IC+DoK:M>Q<RgU]V+W1a5bcf'fk(B")
("20206"	"$B0i5}5~6F6b:h;2<K@FB4BnG0L?LHLULkPUQ=W]gRiM(B")
("20207"	"$B0%2;4'5^73=@?)BUDbDgDkE@FnIiJGJQK_LLM&N<P7QATuTvW?a%(B")
("20208"	"$B2'2F3x6<7,9b???jARC\L=N5NxP8QMQNQOY=ZUa=bCe$jPn](B")
("20209"	"$B555{8#:X>&>OA>IOIZK#N(QKRT]]b6jQj]lEpoqDsC(B")
("20210"	"$B;1>]A=F8HZL5SAT{Y!fElLmc(B")
("20211"	"$B0U4~6YL|N"P9PrQ!cHcIjcp6(B")
("20212"	"$B9Q9kQPTki5jgsn(B")
("20213"	"$BIqK+M+O%cL(B")
("20214"	"$BQQTY(B")
("20215"	"$Bc7jqjwjxs~(B")
("20216"	"$Ba1s}(B")
("20217"	"$BNof@pn(B")
("20218"	"$BlW(B")
("20219"	"$BlZ(B")
("20220"	"$Bs|(B")
("20221"	"$Bpm(B")
("20222"	"$Bb`(B")
("20301"	"$BB@W7(B")
("20302"	"$B5n7;7j9fB~E_TqU`V'gh(B")
("20303"	"$B0B0r1'3F5H7=;e;j;z;{<G<i@e@mB?BpD_EvL>MSTlTrVugigj(B")
("20304"	"$B020m2V3)4#404w5d5f6\7]9(:R;V<5>S>r?D@<@VAWAvB-DhG&GNGdIgJrK'M8O$O4V)V*V,]ggkglgnla(B")
("20305"	"$B081Q1b1q2W2X2j3}414_4d4q596l6u7T9,<B<c=!>0B]ChCwDjEfFMFQF`IDJBJuK[LPLRNjVda7b3cVf5gogpgqgrgsgtgugwgxgygzg{g|g}g~sk(B")
("20306"	"$B0+0q1A5R7)7U9S<<<s=6@`@k@|A0ApAqB{C1C:CcH~IJM(TwU*V4WAcWh!h"h#h%h&h'h(h)h*h+h,h-pj(B")
("20307"	"$B0F0w1W1c2.2H2Y2Z324P5\7s9W:K:u>,EeG|JwMFMiUaUbV6WkWyb4cXf6gvh.h/h0h1h2h3h4h5h6h7h8h9h:h;h<h=h>hOjOl1(B")
("20308"	"$B0`2[334s5F6]8V:Z<d=I>T?r?{AcAkCbCxD[EQF:FRI)JnJxK(L)QrUcUdUeV<V>V@VBVCVFb5cZf7h?h@hAhBhChDhEhFhGhHhIhJhKhLhMhN(B")
("20309"	"$B0*013k3~4(4n6w<f?RA1ArB:F!G#G,GkIYIaIrIxJgMUMnMrN*TdTeTzUfUgV?VHVIcYc[c\hRhWhXhYh[h\h]h^h_h`hahbhdq$t!(B")
("20310"	"$B383w425A7":I;|<,=/>U>x?2?s@yA"AsC_IGJhKkL,L4LXMVTgVLVMWChPhShThUhZhchehfhghhhihjhkhlhmhnhohpsF(B")
("20311"	"$B0~162E2I7&;!<CC%DUG+JNJiJkK)L"L*ThT~UhUiUjUkUlV:VPYk\Mc]gJhqhrhshthuhwhxhy(B")
("20312"	"$B1m5g6><I>V?3B"F"HYIPIsJCMRM\N@OOUmVWa0c_ccf>fHhQhvhzi#i$i|lN(B")
("20313"	"$B1.1r707{?EA&FeGvIyJ3LtLyUnW4XZ_tc`f<hVh{h|h}h~i!i%i&i'i(i)i*i+i,i-i/i0i1i2i3j1(B")
("20314"	"$B3v;'=rNfONVVVXi4i7i8j*kilPm!(B")
("20315"	"$B=sF#HMKzMuW3cacbi.i6i9i:i;i<(B")
("20316"	"$BAIAtC~MvUpf=i"i=i>i?i@iAiBiCiD(B")
("20317"	"$B4`Uo]"]1b<cefAiEiFqZq^(B")
("20318"	"$BV[c^jB(B")
("20319"	"$BV\cfiGjF(B")
("20320"	"$BV^(B")
("20401"	"$BC6P#(B")
("20402"	"$B6$6&8w@hAaNt(B")
("20403"	"$B0I8c9pBEF]G~H]L]M{O.UUUVVcZ]l8(B")
("20404"	"$B0W1j7#979N9z:*:+:S<u>:>;@D@NCiFGI=I`JbW[X}Z^Z_Z`ZaZb[?[@][_U`'fn(B")
("20405"	"$B1N3'3W9+::>J@'@1GVKAODZeZf[+`)(B")
("20406"	"$B5s6398:w;=AGGBTxZgZjh$iP(B")
("20407"	"$B2+2_4S?}@UR(RXZoZpk,(B")
("20408"	"$B6,7J:G;u=k>=?9LlNLZs]^`*`6(B")
("20409"	"$B0&:P=XM@UZZtb7(B")
("20410"	"$BbO(B")
("20411"	"$BK=pQso(B")
("20412"	"$BF^Z~(B")
("20413"	"$B<_(B")
("20414"	"$BgQ(B")
("20417"	"$B[((B")
("20421"	"$Be{(B")
("20501"	"$B>g(B")
("20502"	"$B3-8+8b;y=(CKEXFEJ<O+a6b%b&(B")
("20503"	"$B0Q3X3Y5(6q:J>*BRD9JtRkUWVfVgW8(B")
("20504"	"$B0Z0_1I1e2M3&9D9a;W=U@t@wAUCoE\GXH/H{K?QITtWcWdY<b#f)fqft(B")
("20505"	"$B?ABSBYE^H+N1QJS'__b(c.f*f+gm(B")
("20506"	"$B0[767V;)>oB^CAF2I-N__aa@e'gNj^(B")
("20507"	"$B1D2l3P5.5P>8>vB_EPGcHqKGLcN]\+b$kJsc(B")
("20508"	"$B6H7S:a=pCVX6a3aDf,f-f.if(B")
("20509"	"$B>(>XH3b8(B")
("20510"	"$B2o>^Hmb}f/qN(B")
("20511"	"$B1u2)BcGMQCXmaJrs(B")
("20513"	"$BAQT^f0(B")
("20514"	"$BMef1f2(B")
("20515"	"$Bs^(B")
("20516"	"$Bf#l](B")
("20517"	"$BaHaIf4(B")
("20519"	"$Bf3(B")
("20602"	"$B7t:3<3B6E5IlQ;Q_R%RKRp(B")
("20603"	"$B4,4H7?7@8);Q=-?S@lH\MWRoRxR~T2csgM(B")
("20604"	"$B28545h627*7C7}9|<F=q=z>P?8@TB)NuS-WlWnWs[Y_^ctcucvd$fCfMfN(B")
("20605"	"$B3^4p:V:W:{=,?Z@9BhE+EpI<IdMbVhZla*bDbGcwcxcyczc{c|c}(B")
("20606"	"$B0@6Z:v;g=0AuC'C^EyEzE{H&H5I.NvSE[w\'aAc~d"d#d%d&d8dge1fOi^i_k)(B")
("20607"	"$B8k;q@aAMDBG@K-d!d'd(d)d*d+d,d-d.gOk9l6lGlKlo(B")
("20608"	"$B2U4I;;?iGsI!JOL'bPd/d0d1d2d3d4d5d6d7d9d=(B")
("20609"	"$B4o@}H"H$HOJSSZd:d;d<d>d?p_(B")
("20610"	"$B<DC[FFO6d@dAdBdDdE(B")
("20611"	"$BJ5McRUdCdGdHdIdJdKdLdMdN(B")
("20612"	"$B4JC=J$dOdPdQdRfcj5(B")
("20613"	"$BGFHvJmN|dSdTdUdZk*(B")
("20614"	"$B;<@RSndVdY(B")
("20615"	"$BSodWdXd[d_sv(B")
("20616"	"$BdFd\d](B")
("20617"	"$Bd^d`jC(B")
("20619"	"$Bdak+(B")
("20701"	"$BP4(B")
("20702"	"$Brk(B")
("20703"	"$B?+?0E/TyU0W2(B")
("20704"	"$B0-455t9u<=AbK>M*M|NBX~Zq[\[f`5f|mD(B")
("20705"	"$BHV]9(B")
("20706"	"$B:@T'dldmf:igiijdjf(B")
("20707"	"$B@@KO(B")
("20709"	"$B;A(B")
("20711"	"$BrBs"(B")
("20714"	"$B9l(B")
("20715"	"$BG9(B")
("20717"	"$BjE(B")
("20802"	"$B@IH;RWr.(B")
("20803"	"$B7<<6@cG8GLO,S4TATmU8U:UsWB[p[rsN(B")
("20804"	"$B1@6W<Q=8>GA3AZBXCRGJHaHeH|J2J7OGR)W\X(X*YZ`4p4(B")
("20805"	"$B6XA?EEFDLAMkNmTJ_i`nb,bnp;(B")
("20806"	"$B<{@=H%\F`8e;fGf\f]itjj(B")
("20807"	"$B7E;?<A?LGZNn`rlOmSp<p=p>(B")
("20808"	"$Bj%p9p?p@pApBpC(B")
("20809"	"$B2bAzS[pD(B")
("20810"	"$BpE(B")
("20811"	"$BL8O<pF(B")
("20812"	"$BpG(B")
("20813"	"$BO*[1pH(B")
("20814"	"$BpIpJ(B")
("20816"	"$BjDpKpMpN(B")
("20817"	"$BpO(B")
("20902"	"$B3u(B")
("20903"	"$B1|7xASBDTHVs(B")
("20904"	"$B3Z466r=%>H?U@;A[X4X>_f_h(B")
("20905"	"$BC(JK(B")
("20906"	"$B6[(B")
("20907"	"$B8-l3(B")
("20909"	"$BnZq8(B")
("20911"	"$Bs/(B")
("20912"	"$BjA(B")
("21002"	"$BREde(B")
("21003"	"$B>)A:EITKT|qv(B")
("21004"	"$B7'BVH1X@XBXEXGXJZJ\Q_g_mg0qwqxt&(B")
("21005"	"$B4FHWHXqyqzq{q|q}(B")
("21006"	"$BHKI&q~r!(B")
("21007"	"$B>_Mw(B")
("21008"	"$BbZr"(B")
("21010"	"$Bb_(B")
("21011"	"$Br#rt(B")
("21012"	"$Br$(B")
("21013"	"$Br%(B")
("21014"	"$Br&(B")
("21015"	"$Br'(B")
("21020"	"$Bqj(B")
("21102"	"$B=`@*gPrj(B")
("21103"	"$B=NTOTPT}(B")
("21104"	"$B0V7.7b;C=OG.L[M]XOXQXWX\Yu\[\a^y_q_r`R(B")
("21105"	"$B5z@0Z*Zzb9b~(B")
("21106"	"$BZ)fJf`faj(j.j/sH(B")
("21107"	"$Bkrl4lSlTm&nPsI(B")
("21108"	"$Bo2o4sKsL(B")
("21109"	"$B3>6Al%(B")
("21110"	"$BsM(B")
("21111"	"$Brbs9(B")
("21113"	"$Bsg(B")
("21203"	"$BDFF3J>J@TXVr\h(B")
("21204"	"$B7FX[X`Xa(B")
("21205"	"$BJMb;(B")
("21206"	"$BZMfK(B")
("21207"	"$B7YZ5lUlV(B")
("21208"	"$Bc)(B")
("21210"	"$B6Cdx(B")
("21211"	"$BOI(B")
("21213"	"$BnWsh(B")
("21214"	"$B15(B")
("21302"	"$BQ|(B")
("21303"	"$B:&JIUJU\(B")
("21304"	"$B:)XiXlZ&\{]!g=g>(B")
("21305"	"$B`za2b\sj(B")
("21306"	"$B3*7RSlj~(B")
("21307"	"$Bk4l"m2(B")
("21309"	"$B6BqC(B")
("21311"	"$B:ms?(B")
("21312"	"$BsT(B")
("21402"	"$B6=(B")
("21403"	"$B1ET[(B")
("21404"	"$BD(Xp`!(B")
("21405"	"$B<%(B")
("21406"	"$Bf"(B")
("21408"	"$BoH(B")
("21409"	"$BpT(B")
("21412"	"$Bsa(B")
("21415"	"$B]5`&(B")
("21502"	"$BMARY(B")
("21507"	"$Bk5(B")
("21509"	"$Bp~(B")
("21602"	"$BRV(B")
("21603"	"$BTb(B")
("21604"	"$B7|(B")
("21606"	"$B=1O8(B")
("21607"	"$B=2(B")
("21903"	"$B7%V]W>(B")
("21904"	"$BXxZ;ZN]3(B")
("21906"	"$BgHjG(B")
("21908"	"$BoV(B")
("21911"	"$BsB(B")
("22005"	"$BsE(B")
("22008"	"$BoX(B")
("30101"	"$BEaG5R8(B")
("30102"	"$B?O(B")
("30104"	"$B;J(B")
("30107"	"$BD>(B")
("30201"	"$B;3<[@#K^K|Uw(B")
("30202"	"$B1_6'6T6h7n8{;_;aEMFwH?I$L^LqM'P<(B")
("30203"	"$B051&2D6g:8@M@PAYB|I[JqMQQER2RH(B")
("30204"	"$B003%6)9!:_=H=\>"B8F1FdM-Q^R3f&(B")
("30205"	"$B0eC$QHR4R:VbiI(B")
("30206"	"$B2,2h<~H!f((B")
("30207"	"$B8|=bIwM)NRQbR5RMY((B")
("30208"	"$B86F?H[(B")
("30209"	"$BQ`R6R?RNlD(B")
("30210"	"$B4g?_RORP(B")
("30211"	"$B19R;ro(B")
("30212"	"$B1^K1NqNrR<RQRR(B")
("30213"	"$BR=rn(B")
("30215"	"$BTZ(B")
("30217"	"$B4f(B")
("30222"	"$Br6(B")
("30301"	"$BD^F|L`P![)(B")
("30302"	"$B1;5p9-9~;M<|=h?,D#DTEDFtHiJUL1L\P1(B")
("30303"	"$B0x1*2s8~<0=d>1?T?WC)CDKx(B")
("30304"	"$B0O1~6I6a7^:$=x>2?C?^DnG"H_HxJVSyU{(B")
("30305"	"$B1d2`5o6~8G9.9q=RDlE3E9FOFvGwI\JySzU|W/ml(B")
("30306"	"$B202v5U7z;SAwB`CkDIEYF(G6LBS{S|U}V"Vy(B")
("30307"	"$B0)6}8K:B?`@B@JB$B.C`DLDmD~E8ESEbF)GgJ`O"S}U~V!(B")
("30308"	"$B0C0o9/</=5=n?JBaKcMGS~T!T"lI(B")
("30309"	"$B1?2a6x7w:T<H?kB0C#CYEKF;F[GQI/JWM7MZO-T#V#VzV{lH(B")
("30310"	"$B0c1`1s8/ALB=NwO!T$V|(B")
("30311"	"$B3G<W?PAXAxE,FPIeT%T&VwV}V~W!(B")
("30312"	"$B0d7D=e>3A*A+I@K`MzNKW"W#W$W%W&W']`(B")
("30313"	"$B4THrKaT(W(W)sG(B")
("30314"	"$BXfdve[g?(B")
("30315"	"$BK{(B")
("30316"	"$BW*sS(B")
("30317"	"$BW-(B")
("30318"	"$BKbV$W+(B")
("30321"	"$BBkN[(B")
("30322"	"$BW,(B")
("30401"	"$Bmh(B")
("30402"	"$B4m5$9M=?FuFyO7iH(B")
("30403"	"$B2|7/9'Ux(B")
("30404"	"$B0?8W<TIp]d`(mi(B")
("30405"	"$B4G5TH}S!mjmkmm(B")
("30406"	"$B]e]ffBiJmompmqmrm~(B")
("30407"	"$B5uQ]]\msmtmumvmwmxmymzn%(B")
("30408"	"$B]_m{m|m}n!(B")
("30409"	"$B6sN:n"n#n$n&n'n((B")
("30410"	"$Bn)n*t#(B")
("30411"	"$BIfN8n+n,(B")
("30412"	"$BZ{b:n-n/(B")
("30413"	"$Bn0n1n2n3(B")
("30414"	"$Bcdmnn5(B")
("30415"	"$Bn4(B")
("30419"	"$Bn6(B")
("30502"	"$Ba#aK(B")
("30503"	"$Ba$aLaM(B")
("30504"	"$B1VZda&a'a(aNaO(B")
("30505"	"$B<@>I?>HhIBaPaQaRaTaUaVaW(B")
("30506"	"$B:/<&a)aSaXaYaZ(B")
("30507"	"$BDKEwN!a[a\a](B")
("30508"	"$BCTa^a_a`aaabacadae(B")
("30509"	"$Ba-afagah(B")
("30510"	"$BAiaiajakalaman(B")
("30511"	"$Baoapaq(B")
("30512"	"$B4b87NEarasat(B")
("30513"	"$BJJL~auav(B")
("30514"	"$Baw(B")
("30515"	"$Bax(B")
("30516"	"$Bayaza{a|(B")
("30517"	"$Ba}(B")
("30518"	"$Ba~(B")
("30519"	"$Bb!(B")
("30603"	"$B:HI'S%(B")
("30604"	"$B1(:OGO(B")
("30605"	"$B;:(B")
("30606"	"$B:[(B")
("30607"	"$B:\(B")
("30608"	"$BY#(B")
("30612"	"$BBW(B")
("30702"	"$BIkQn(B")
("30703"	"$B5/:9EgUqlb(B")
("30704"	"$BD;sP(B")
("30705"	"$B1[CeD6a4lcsR(B")
("30707"	"$Bld(B")
("30708"	"$B9m<q(B")
("30709"	"$BLM(B")
("30710"	"$B?v(B")
("30801"	"$BoY(B")
("30802"	"$BA.JY(B")
("30803"	"$BI7JDLdoZo[(B")
("30804"	"$B1<3+4V4WLeo\o](B")
("30805"	"$Bo^o_o`(B")
("30806"	"$B3U4X9^H6J9oaob(B")
("30807"	"$B1\L%oc(B")
("30808"	"$Bodoeofog(B")
("30809"	"$B0Gohojokol(B")
("30810"	"$BF.omonoo(B")
("30811"	"$Bop(B")
("30812"	"$Boq(B")
("30813"	"$Boros(B")
("30902"	"$B:|(B")
("30905"	"$Bq&(B")
("30908"	"$Bq'(B")
("30909"	"$BBj(B")
("30911"	"$Bq)(B")
("31004"	"$B3!(B")
("31005"	"$Br)r1(B")
("31006"	"$Br*(B")
("31008"	"$Br+r3r4(B")
("31010"	"$Br,(B")
("31011"	"$Br5(B")
("31016"	"$Br-(B")
("31104"	"$BsO(B")
("31305"	"$Bsl(B")
("401"	"$B250lP&P(P-(B")
("402"	"$BCzKtN;QDQLQ\R9R>RGRL<7P5Qa==6e?MF~KNNOP)R1RS(B")
("403"	"$B2<435W5Z5]8J8}9):5;RL&M<P2Q:QcSxTiTjUSUyVaW.;N>eEZK4LiW@6R:M@iV%W04]=w>fBgG7M?U_VvVxW5(B")
("404"	"$B1/2&2g8^8_<\C0D$E7GCITP"UzZ[]F]Y?QF{0f5m<j>#CfFVLSLZ2P8$>/FbIWJRLhRAToTpXy`-(B")
("405"	"$B1z3n4$6L9C:};.@5FLI%J:J?JlQFZ\4E5V=P@$@8GrM3RB2S8C?=FcH>K\KvL$[21{;K<:J&JjP'QGXz(B")
("406"	"$B:1:F;`<*@>N>OJRDk(116J7l<+<kCnJF[3fPff0P1H=.@.MyX{X|(B")
("407"	"$B0!99FSN$V`l5:A2f5a6z<V?HB+HPJcMhP/<wEFNITs[*(B")
("408"	"$B1+2LP3Q@?bp2;vElP*PTc=p0(B")
("409"	"$BHt=Epl>h[Kc;c<0R0YRygL(B")
("410"	"$BT1P+(B")
("411"	"$B=M@LAV(B")
("412"	"$B4v(B")
("413"	"$BE$sffi(B")
("414"	"$B<$(B")
("415"	"$B5&gI(B")
)
